/*
Copyright (c) 2002-2011 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/

// INCLUDE FILES
#include <avkon.hrh>
#include <rps_0xA00054BC.rsg>

#include "common.hrh"
#include "rps.hrh"
#include "rpsApplication.h"
#include "rpsAppUi.h"
#include "rpsAppView.h"

TInt gScreenWidth;
TInt gScreenHeight;

// -----------------------------------------------------------------------------
// CRpsAppUi::ConstructL()
// Symbian 2nd phase constructor can leave.
// -----------------------------------------------------------------------------
//
void CRpsAppUi::ConstructL()
	{
	// Initialise app UI with standard value.
	BaseConstructL(CAknAppUi::EAknEnableSkin);

	// Remove key blocking.
	SetKeyBlockMode(ENoKeyBlock);
	
	gScreenWidth = ClientRect().Width();
	gScreenHeight = ClientRect().Height();
	
	iGameEngine = CRpsGameEngine::NewL(*this);

	// Create view object
	iAppView = CRpsAppView::NewL(*iGameEngine, ClientRect());
	AddToStackL(iAppView);

	}
// -----------------------------------------------------------------------------
// CRpsAppUi::CRpsAppUi()
// C++ default constructor can NOT contain any code, that might leave.
// -----------------------------------------------------------------------------
//
CRpsAppUi::CRpsAppUi()
	{
	// No implementation required
	}

// -----------------------------------------------------------------------------
// CRpsAppUi::~CRpsAppUi()
// Destructor.
// -----------------------------------------------------------------------------
//
CRpsAppUi::~CRpsAppUi()
	{
	delete iGameEngine;
	if (iAppView)
		{
		RemoveFromStack(iAppView);
		delete iAppView;
		}
	}

// -----------------------------------------------------------------------------
// CRpsAppUi::HandleCommandL()
// Takes care of command handling.
// -----------------------------------------------------------------------------
//
void CRpsAppUi::HandleCommandL( TInt aCommand )
	{
	switch( aCommand )
		{
		case EEikCmdExit:
		case EAknSoftkeyExit:
		case EAknSoftkeyBack:
			Exit();
			break;
		default:
			ASSERT(EFalse); // Should not get here
			break;
		}
	}
// -----------------------------------------------------------------------------
//  Called by the framework when the application status pane
//  size is changed.  Passes the new client rectangle to the
//  AppView
// -----------------------------------------------------------------------------
//
void CRpsAppUi::HandleStatusPaneSizeChange()
	{
	iAppView->SetRect( ClientRect() );
	} 

void CRpsAppUi::UpdateScreen()
	{
	iAppView->DrawNow();
	}

// End of File
